@@ -1,9 +1,18 @@
+import os
 import sys
-from pyspecs._runner import Step, _counter, _step_runner
+import time
+from pyspecs._reporting import ConsoleReporter
+from pyspecs._runner import _StepRunner
 from pyspecs._should import _Should
+from pyspecs._step import Step, _StepCounter
 
 
-__version__ = '2.0'
+__version__ = '2.1'
+
+
+_reporter = ConsoleReporter()
+_counter = _StepCounter(_reporter, time.time)
+_step_runner = _StepRunner(_reporter)
 
 
 given = Step('given', _counter)
@@ -32,7 +41,7 @@ def catch(callable_):
     try:
         callable_()
     except:
-        return sys.exc_info()
+        return sys.exc_info()[1]
     else:
         return None
     finally:
